Reference Deploy Architectures
==============================

This section covers the way we recommend the Bare Metal service to be deployed
and managed. It is assumed that a reader has already gone through
:doc:`/user/index`. It may be also useful to try :ref:`deploy_devstack` first
to get better familiar with the concepts used in this guide.

.. toctree::
   :maxdepth: 2

   common

Scenarios
---------

.. toctree::
   :maxdepth: 2

   small-cloud-trusted-tenants
